pthread_barrierattr_destroy

Function pthread_barrierattr_destroy 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pthread_barrierattr_destroy( attr: *mut pthread_barrierattr_t, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/pthread_barrierattr_destroy.html.

Destroys a barrier attributes object.

Upon success, returns 0. Upon error, returns an error number.

Implementation

Not async-signal-safe.

Safety

Undefined behaviour will occur if attr is uninitialized or if attr is used after calling this function.