pthread_barrierattr_getpshared

Function pthread_barrierattr_getpshared 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pthread_barrierattr_getpshared( attr: *const pthread_barrierattr_t, pshared: *mut c_int, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/pthread_barrierattr_getpshared.html.

Obtains the value of the process-shared attribute from the attributes object referenced by attr.

Upon success, returns 0 and stores the value of the process-shared attribute of attr into the object referenced by pshared. Upon error, returns an error number.

Implementation

Not async-signal-safe.

Safety

Undefined behaviour will occur if attr is uninitialized.