#[unsafe(no_mangle)]pub unsafe extern "C" fn pthread_barrier_destroy(
barrier: *mut pthread_barrier_t,
) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/pthread_barrier_destroy.html.
Destroys the barrier referenced by barrier and releases any resources
used by the barrier.
Upon success, returns 0. Upon error, returns an error number.
Implementation
Not async-signal-safe.
Safety
The following will result in undefined behaviour:
- Use of
barrierafter this function unless reinitialized bypthread_barrier_init(). - This function is called with an uninitialized
barrier. - This function is called when any thread is blocked on
barrier.