#[unsafe(no_mangle)]pub unsafe extern "C" fn pthread_barrierattr_init(
attr: *mut pthread_barrierattr_t,
) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/pthread_barrierattr_init.html.
Initializes a barrier attributes object attr with the default value of
all of the attributes defined by the implementation.
Upon success, returns 0. Upon error, returns an error number.
Implementation
Not async-signal-safe.
Safety
Undefined behaviour will occur if attr is already initialized.